@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2003 the xine project
+ * Copyright (C) 2001-2005 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -22,7 +22,7 @@
  * MS WAV File Demuxer by Mike Melanson (melanson@pcisys.net)
  * based on WAV specs that are available far and wide
  *
- * $Id: demux_wav.c,v 1.60 2004/06/14 19:15:36 hadess Exp $
+ * $Id: demux_wav.c,v 1.60.2.1 2005/07/17 21:49:58 miguelfreitas Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -121,6 +121,11 @@ static int open_wav_file(demux_wav_t *this) {
     this->audio_type = BUF_AUDIO_UNKNOWN;
   }
 
+  if (this->wave->nChannels <= 0) {
+    free (this->wave);
+    return 0;
+  }
+
   /* traverse through the chunks to find the 'data' chunk */
   this->data_start = this->data_size = 0;
   while (this->data_start == 0) {
@@ -141,39 +146,6 @@ static int open_wav_file(demux_wav_t *this) {
       this->input->seek(this->input, chunk_size, SEEK_CUR);
     }
   }
-  if (this->audio_type == BUF_AUDIO_LPCM_LE) {
-    if (this->input->read(this->input, chunk_preamble, 6) != 6 ) {
-      free (this->wave);
-      return 0;
-    }
-    /* rewind the amount we just read */
-    this->input->seek(this->input, -6, SEEK_CUR);
-
-    if (chunk_preamble[0] == 0x72 &&
-        chunk_preamble[1] == 0xf8 &&
-        chunk_preamble[2] == 0x1f &&
-        chunk_preamble[3] == 0x4e ) {
-      this->audio_type = BUF_AUDIO_DNET;
-    }
-    if (chunk_preamble[0] == 0xff &&
-        chunk_preamble[1] == 0x1f &&
-        chunk_preamble[2] == 0x00 &&
-        chunk_preamble[3] == 0xe8 &&
-        chunk_preamble[4] == 0xf1 &&    /* DTS standard document was wrong here! */
-        chunk_preamble[5] == 0x07 ) {   /* DTS standard document was wrong here! */
-      this->audio_type = BUF_AUDIO_DTS; /* DTS but in 14bit format. */
-    }
-#if 0
-    printf("Preamble=%02x %02x %02x %02x %02x %02x\n",
-        chunk_preamble[0],
-        chunk_preamble[1],
-        chunk_preamble[2],
-        chunk_preamble[3],
-        chunk_preamble[4],
-        chunk_preamble[5]);
-#endif
-
-  }
 
   return 1;
 }
@@ -238,16 +210,6 @@ static int demux_wav_send_chunk(demux_plugin_t *this_gen) {
     printf("\n");
 #endif
 
-    if (this->audio_type == BUF_AUDIO_LPCM_LE) {
-      if (buf->content[0] == 0x72 &&
-          buf->content[1] == 0xf8 &&
-          buf->content[2] == 0x1f &&
-          buf->content[3] == 0x4e ) {
-        this->audio_type = BUF_AUDIO_DNET;
-      }
-    } else if (this->audio_type == BUF_AUDIO_DNET) {
-      buf->pts=0; /* We don't need pts values for only audio streams. */
-    }
 #if 0
     for(n=0;n<20;n++) {
       printf("%x ",buf->content[n]);
