@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: audio_filters.c,v 1.2 2004/07/27 17:59:58 mroi Exp $
+ * $Id: audio_filters.c,v 1.2.2.1 2005/07/17 21:50:05 miguelfreitas Exp $
  *
  * catalog for audio filter plugins
  */
@@ -30,13 +30,15 @@
 #include "audio_filters.h"
 
 
-post_info_t upmix_special_info   = { XINE_POST_TYPE_AUDIO_FILTER };
-post_info_t stretch_special_info = { XINE_POST_TYPE_AUDIO_FILTER };
+post_info_t upmix_special_info      = { XINE_POST_TYPE_AUDIO_FILTER };
+post_info_t upmix_mono_special_info = { XINE_POST_TYPE_AUDIO_FILTER };
+post_info_t stretch_special_info    = { XINE_POST_TYPE_AUDIO_FILTER };
 
 
 plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
-  { PLUGIN_POST, 9, "upmix", XINE_VERSION_CODE, &upmix_special_info, &upmix_init_plugin },
-  { PLUGIN_POST, 9, "stretch", XINE_VERSION_CODE, &stretch_special_info, &stretch_init_plugin },
-  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
+  { PLUGIN_POST, 9, "upmix",      XINE_VERSION_CODE, &upmix_special_info,      &upmix_init_plugin },
+  { PLUGIN_POST, 9, "upmix_mono", XINE_VERSION_CODE, &upmix_mono_special_info, &upmix_mono_init_plugin },
+  { PLUGIN_POST, 9, "stretch",    XINE_VERSION_CODE, &stretch_special_info,    &stretch_init_plugin },
+  { PLUGIN_NONE, 0, "",           0,                 NULL,                     NULL }
 };
