@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: buffer.h,v 1.145.2.3 2005/04/25 14:43:17 mroi Exp $
+ * $Id: buffer.h,v 1.145.2.4 2005/07/17 21:50:14 miguelfreitas Exp $
  *
  *
  * contents:
@@ -169,6 +169,16 @@ extern "C" {
 #define BUF_VIDEO_FLV1		0x024C0000
 #define BUF_VIDEO_H264		0x024D0000
 #define BUF_VIDEO_MJPEG_B	0x024E0000
+#define BUF_VIDEO_H261		0x024F0000
+#define BUF_VIDEO_AASC		0x02500000
+#define BUF_VIDEO_LOCO		0x02510000
+#define BUF_VIDEO_QDRW		0x02520000
+#define BUF_VIDEO_QPEG		0x02530000
+#define BUF_VIDEO_ULTI		0x02540000
+#define BUF_VIDEO_WNV1		0x02550000
+#define BUF_VIDEO_XL		0x02560000
+#define BUF_VIDEO_RT21		0x02570000
+#define BUF_VIDEO_FPS1		0x02580000
 
 /* audio buffer types:  (please keep in sync with buffer_types.c) */
 
@@ -228,6 +238,8 @@ extern "C" {
 #define BUF_AUDIO_XAN_DPCM	0x03330000
 #define BUF_AUDIO_ALAC		0x03340000
 #define BUF_AUDIO_MPC		0x03350000
+#define BUF_AUDIO_SHORTEN	0x03360000
+#define BUF_AUDIO_WESTWOOD_SND1	0x03370000
 #define BUF_AUDIO_WMALL		0x03380000
 
 /* spu buffer types:    */
