@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: buffer_types.c,v 1.89.2.3 2005/04/25 14:43:17 mroi Exp $
+ * $Id: buffer_types.c,v 1.89.2.4 2005/07/17 21:50:14 miguelfreitas Exp $
  *
  *
  * contents:
@@ -63,6 +63,7 @@ static video_db_t video_db[] = {
 {
   {
     meFOURCC('m', 'p', 'e', 'g'),
+    meFOURCC('M', 'P', 'E', 'G'),
     meFOURCC('P', 'I', 'M', '1'),
     meFOURCC('m', 'p', 'g', '2'),
     meFOURCC('m', 'p', 'g', '1'),
@@ -572,6 +573,7 @@ static video_db_t video_db[] = {
 {
   {
     meFOURCC('I', 'M', 'G', ' '),
+    meFOURCC('g', 'i', 'f', ' '),
     0,
   },
   BUF_VIDEO_IMAGE,
@@ -646,11 +648,87 @@ static video_db_t video_db[] = {
   {
     meFOURCC('a','v','c','1'),
     meFOURCC('h','2','6','4'),
+    meFOURCC('H','2','6','4'),
     0
   },
   BUF_VIDEO_H264,
   "Advanced Video Coding (H264)"
 },
+{
+  {
+    meFOURCC('A','A','S','C'),
+    0
+  },
+  BUF_VIDEO_AASC,
+  "Autodesk Animator Studio Codec"
+},
+{
+  {
+    meFOURCC('q','d','r','w'),
+    0
+  },
+  BUF_VIDEO_QDRW,
+  "QuickDraw"
+},
+{
+  {
+    meFOURCC('L','O','C','O'),
+    0
+  },
+  BUF_VIDEO_LOCO,
+  "LOCO"
+},
+{
+  {
+    meFOURCC('U','L','T','I'),
+    0
+  },
+  BUF_VIDEO_ULTI,
+  "IBM UltiMotion"
+},
+{
+  {
+    meFOURCC('W','N','V','1'),
+    0
+  },
+  BUF_VIDEO_WNV1,
+  "Winnow Video"
+},
+{
+  {
+    meFOURCC('P','I','X','L'),
+    meFOURCC('X','I','X','L'),
+    0
+  },
+  BUF_VIDEO_XL,
+  "Miro/Pinnacle VideoXL"
+},
+{
+  {
+    meFOURCC('Q','P','E','G'),
+    meFOURCC('Q','1','.','0'),
+    meFOURCC('Q','1','.','1'),
+    0
+  },
+  BUF_VIDEO_QPEG,
+  "Q-Team QPEG Video"
+},
+{
+  {
+    meFOURCC('R','T','2','1'),
+    0
+  },
+  BUF_VIDEO_RT21,
+  "Winnow Video"
+},
+{
+  {
+    meFOURCC('F','P','S','1'),
+    0
+  },
+  BUF_VIDEO_FPS1,
+  "Fraps FPS1"
+},
 { { 0 }, 0, "last entry" }
 };
 
