@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: configfile.c,v 1.73.2.2 2005/04/20 17:21:15 mroi Exp $
+ * $Id: configfile.c,v 1.73.2.3 2005/07/21 02:57:52 miguelfreitas Exp $
  *
  * config object (was: file) management - implementation
  *
@@ -801,11 +801,14 @@ static void config_update_num (config_values_t *this,
     xine_cfg_entry_t cb_entry;
 
     config_shallow_copy(&cb_entry, entry);
-    /* do not enter the callback from within a locked context */
-    pthread_mutex_unlock(&this->config_lock);
+    
+    /* it is safe to enter the callback from within a locked context
+     * because we use a recursive mutex.
+     */
     entry->callback (entry->callback_data, &cb_entry);
-  } else
-    pthread_mutex_unlock(&this->config_lock);
+  }
+  
+  pthread_mutex_unlock(&this->config_lock);
 }
 
 static void config_update_string (config_values_t *this,
@@ -850,8 +853,10 @@ static void config_update_string (config_values_t *this,
     xine_cfg_entry_t cb_entry;
 
     config_shallow_copy(&cb_entry, entry);
-    /* FIXME: find a solution which does not enter the callback with the lock acquired,
-     * but does also handle the char* leak- and race-free without unnecessary string copying */
+    
+    /* it is safe to enter the callback from within a locked context
+     * because we use a recursive mutex.
+     */
     entry->callback (entry->callback_data, &cb_entry);
   }
 
@@ -1159,6 +1164,7 @@ config_values_t *_x_config_init (void) {
   volatile /* is this a (old, 2.91.66) irix gcc bug?!? */
 #endif
   config_values_t *this;
+  pthread_mutexattr_t attr;
 
   if (!(this = xine_xmalloc(sizeof(config_values_t)))) {
 
@@ -1170,7 +1176,12 @@ config_values_t *_x_config_init (void) {
   this->last  = NULL;
   this->current_version = 0;
 
-  pthread_mutex_init(&this->config_lock, NULL);
+  /* warning: config_lock is a recursive mutex. it must NOT be
+   * used with neither pthread_cond_wait() or pthread_cond_timedwait()
+   */
+  pthread_mutexattr_init(&attr);
+  pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+  pthread_mutex_init(&this->config_lock, &attr);
 
   this->register_string     = config_register_string;
   this->register_range      = config_register_range;
